@@ -60,13 +60,12 @@ typedef struct _GomMinerPrivate GomMinerPrivate;
 
 typedef struct {
   GomMiner *miner;
-  TrackerSparqlConnection *connection; /* borrowed from GomMiner */
-  gulong miner_cancellable_id;
+  TrackerSparqlConnection *connection;
 
   GoaAccount *account;
   GHashTable *services;
-  GSimpleAsyncResult *async_result;
-  GCancellable *cancellable;
+  GTask *task;
+  GTask *parent_task;
 
   GHashTable *previous_resources;
   gchar *datasource_urn;
@@ -88,10 +87,28 @@ struct _GomMinerClass
   char *miner_identifier;
   gint  version;
 
+  gpointer (*create_service) (GomMiner *self, GoaObject *object, const gchar *type);
+
   GHashTable * (*create_services) (GomMiner *self,
                                    GoaObject *object);
 
+  void (*destroy_service) (GomMiner *self, gpointer service);
+
+  void (*insert_shared_content) (GomMiner *self,
+                                 gpointer service,
+                                 TrackerSparqlConnection *connection,
+                                 const gchar *datasource_urn,
+                                 const gchar *shared_id,
+                                 const gchar *shared_type,
+                                 const gchar *source_urn,
+                                 GCancellable *cancellable,
+                                 GError **error);
+
   void (*query) (GomAccountMinerJob *job,
+                 TrackerSparqlConnection *connection,
+                 GHashTable *previous_resources,
+                 const gchar *datasource_urn,
+                 GCancellable *cancellable,
                  GError **error);
 };
 
@@ -99,6 +116,17 @@ GType gom_miner_get_type (void);
 
 const gchar * gom_miner_get_display_name (GomMiner *self);
 
+void gom_miner_insert_shared_content_async (GomMiner *self,
+                                            const gchar *account_id,
+                                            const gchar *shared_id,
+                                            const gchar *shared_type,
+                                            const gchar *source_urn,
+                                            GCancellable *cancellable,
+                                            GAsyncReadyCallback callback,
+                                            gpointer user_data);
+
+gboolean gom_miner_insert_shared_content_finish (GomMiner *self, GAsyncResult *res, GError **error);
+
 void gom_miner_refresh_db_async (GomMiner *self,
                                  GCancellable *cancellable,
                                  GAsyncReadyCallback callback,
